#[repr(transparent)]pub struct Control(pub u32);Expand description
PowerQuad Control register
Tuple Fields
0: u32Implementations
Sourceimpl Control
impl Control
Sourcepub const fn decode_opcode(&self) -> u8
pub const fn decode_opcode(&self) -> u8
opcode specific to decode_machine
Sourcepub const fn set_decode_opcode(&mut self, val: u8)
pub const fn set_decode_opcode(&mut self, val: u8)
opcode specific to decode_machine
Sourcepub const fn decode_machine(&self) -> u8
pub const fn decode_machine(&self) -> u8
0 : Coprocessor , 1 : matrix , 2 : fft , 3 : fir , 4 : stat , 5 : cordic , 6 -15 : NA
Sourcepub const fn set_decode_machine(&mut self, val: u8)
pub const fn set_decode_machine(&mut self, val: u8)
0 : Coprocessor , 1 : matrix , 2 : fft , 3 : fir , 4 : stat , 5 : cordic , 6 -15 : NA
Sourcepub const fn inst_busy(&self) -> bool
pub const fn inst_busy(&self) -> bool
Instruction busy signal when high indicates processing is on
Sourcepub const fn set_inst_busy(&mut self, val: bool)
pub const fn set_inst_busy(&mut self, val: bool)
Instruction busy signal when high indicates processing is on